@@ -86,14 +86,6 @@ Provides an endpoint to the functionality described in L<Catalyst::Controller::D
 
 =cut 
 
-sub begin :Private {
-	my ($self, $c) = @_;
-
-	$c->forward('deserialize');
-	$c->req->params($c->req->data);
-	$self->NEXT::begin($c);	
-}
-
 # from Catalyst::Action::Serialize
 sub deserialize :ActionClass('Deserialize') {
 	my ($self, $c) = @_;
